@@ -23,12 +23,13 @@ from puke.SSH import SSH
 import puke.System
 import puke.FileSystem
 import puke.Utils
+import requests as http
 
 
 VERSION = 0.1
 __all__ = [
             "main", "VERSION", "Error", "FileList", "Sed", "Std", "Env", "Require", "Yak", "VirtualEnv", "System", "FileSystem", "Utils",
-            "combine", "sh", "minify", "jslint", "jsdoc", "patch", "prompt", "deepcopy", "stats", "pack", "unpack", "hsizeof", "console", "SSH"
+            "combine", "sh", "minify", "jslint", "http", "jsdoc", "jsdoc3", "patch", "prompt", "deepcopy", "stats", "pack", "unpack", "hsizeof", "console", "SSH"
          ]
 
 
@@ -64,7 +65,8 @@ def run():
 
     (options, args) = parser.parse_args()
 
-
+    rLog = logging.getLogger('requests')
+    rLog.setLevel(logging.WARNING)
     #
     # Configure logging
     # 
@@ -75,6 +77,7 @@ def run():
     elif not logging.root.handlers:
         if options.verbose is True:
             logging.getLogger().setLevel(logging.DEBUG)
+            rLog.setLevel(logging.DEBUG)
         elif options.verbose is False:
             logging.getLogger().setLevel(logging.WARN)
         else:
